package com.muyu.common.nacos.remote.interceptor;

import com.dtflys.forest.http.ForestRequest;
import com.dtflys.forest.interceptor.Interceptor;
import com.muyu.common.core.text.Convert;
import com.muyu.common.core.utils.StringUtils;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Value;

@Log4j2
public class NacosNamespaceInterceptor<T> implements Interceptor<T> {


    @Value("${nacos.namespace}")
    private String namespaceId;


    /**
     * 该方法在请求发送之前被调用, 若返回false则不会继续发送请求
     * @Param request Forest请求对象
     */
    @Override
    public boolean beforeExecute(ForestRequest req) {
        if(StringUtils.isNotEmpty(namespaceId)){
            // 执行在发送请求之前处理的代码
            Object reqNamespaceId =Convert.utf8Str( req.getQuery("namespaceId"));
            if(reqNamespaceId==null){
                log.warn("本次请求nacos的namespaceId未携带，已添加[{}]",namespaceId);
                req.addQuery("namespaceId", namespaceId);  // 添加URL的Query参数
            }else {
                if(StringUtils.equals(Convert.str(reqNamespaceId,""),namespaceId)){
                    log.warn("本次请求nacos的namespaceId和项目ID不符合,现已更改:[{}->{}]",reqNamespaceId,namespaceId);
                    req.addQuery("namespaceId", namespaceId);  // 添加URL的Query参数
                }
            }
        }



        return true;  // 继续执行请求返回true
    }

}

